@@ -24,6 +24,11 @@
 #undef tznm
 #undef mjed
 
+/* Various phrases that need to be repeated frequently in docstrings. */
+
+#define D " as a float giving radians, or a string giving degrees:minutes:seconds"
+#define H " as a float giving radians, or a string giving hours:minutes:seconds"
+
 /* Since different Body attributes are calculated with different
    routines, the compute() function itself just writes the time into
    the Body's `now' cache, and the VALID bits - stored in the user
@@ -321,7 +326,8 @@ static PyTypeObject AngleType = {
      0,				/* tp_setattro */
      0,				/* tp_as_buffer */
      Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE, /* tp_flags */
-     0,				/* tp_doc */
+     "An angle in radians that can print itself in an astronomical format.\n"
+     "Use ephem.degrees() and ephem.radians() to create one.", /* tp_doc */
      0,				/* tp_traverse */
      0,				/* tp_clear */
      0,				/* tp_richcompare */
@@ -372,12 +378,12 @@ static int parse_mjd_from_string(PyObject *so, double *mjdp)
 	  goto fail;
 
      if (len >= 1) {
+	  int i;
           char *s = MyString_AsString(PyList_GetItem(pieces, 0));
           if (!s) goto fail;
 
 	  /* Make sure all characters are in set '-/.0123456789' */
 
-	  int i;
 	  for (i=0; s[i]; i++) {
 	       if (s[i] != '-' && s[i] != '/' && s[i] != '.'
 		   && (s[i] < '0' || s[i] > '9')) {
@@ -581,7 +587,11 @@ static PyTypeObject DateType = {
      0,				/* tp_setattro */
      0,				/* tp_as_buffer */
      Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE, /* tp_flags */
-     0,				/* tp_doc */
+     "Floating point value used by ephem to represent a date.\n"
+     "The value is the number of days since 1899 December 31 12:00 UT. When\n"
+     "creating an instance you can pass in a Python datetime instance,"
+     " timetuple,\nyear-month-day triple, or a plain float. Run str() on"
+     "this object to see\nthe UTC date it represents.", /* tp_doc */
      0,				/* tp_traverse */
      0,				/* tp_clear */
      0,				/* tp_richcompare */
@@ -676,15 +686,15 @@ static double to_angle(PyObject *value, double efactor, int *status)
 
 /* Hours stored as radian double. */
 
-static PyObject* getf_rh(PyObject *self, void *v)
+static PyObject* getd_rh(PyObject *self, void *v)
 {
-     return new_Angle(THE_FLOAT, radhr(1));
+     return new_Angle(THE_DOUBLE, radhr(1));
 }
 
-static int setf_rh(PyObject *self, PyObject *value, void *v)
+static int setd_rh(PyObject *self, PyObject *value, void *v)
 {
      int status;
-     THE_FLOAT = (float) to_angle(value, radhr(1), &status);
+     THE_DOUBLE = to_angle(value, radhr(1), &status);
      return status;
 }
 
@@ -943,7 +953,7 @@ static PyObject *Observer_radec_of(PyObject *self, PyObject *args,
      if (!rao) return 0;
      deco = new_Angle(dec, raddeg(1));
      if (!deco) return 0;
-     return Py_BuildValue("OO", rao, deco);
+     return Py_BuildValue("NN", rao, deco);
 }
 
 /*
@@ -994,22 +1004,27 @@ static PyMethodDef Observer_methods[] = {
 
 static PyGetSetDef Observer_getset[] = {
      {"date", getd_mjd, setd_mjd, "Date", VOFF(n_mjd)},
-     {"lat", getd_rd, setd_rd, "Latitude (degrees north)", VOFF(n_lat)},
-     {"long", getd_rd, setd_rd, "Longitude (degrees east)", VOFF(n_lng)},
+     {"lat", getd_rd, setd_rd, "Latitude north of the Equator" D, VOFF(n_lat)},
+     {"lon", getd_rd, setd_rd, "Longitude east of Greenwich" D, VOFF(n_lng)},
      {"elevation", get_elev, set_elev,
-      "Elevation above sea level (meters)", NULL},
+      "Elevation above sea level in meters", NULL},
      {"horizon", getd_rd, setd_rd,
       "The angle above (+) or below (-) the horizon at which an object"
-      " should be considered at the moment of rising or setting (degrees)",
+      " should be considered at the moment of rising or setting" D,
       VOFF(n_dip)},
      {"epoch", getd_mjd, setd_mjd, "Precession epoch", VOFF(n_epoch)},
+
+     /* For compatibility with older scripts: */
+     {"long", getd_rd, setd_rd, "Longitude east of Greenwich" D, VOFF(n_lng)},
+
      {NULL}
 };
 
 static PyMemberDef Observer_members[] = {
-     {"temp", T_DOUBLE, OFF(n_temp), 0, "atmospheric temperature (C)"},
+     {"temp", T_DOUBLE, OFF(n_temp), 0,
+      "atmospheric temperature in degrees Celsius"},
      {"pressure", T_DOUBLE, OFF(n_pressure), 0,
-      "atmospheric pressure (mBar)"},
+      "atmospheric pressure in millibar"},
      {NULL}
 };
 
@@ -1036,7 +1051,11 @@ static PyTypeObject ObserverType = {
      0,				/* tp_setattro */
      0,				/* tp_as_buffer */
      Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE,	/* tp_flags */
-     0,				/* tp_doc */
+     "Describes an observer standing on the Earth's surface.\n"
+     "This object can also store the time at which the observer is watching;\n"
+     "the epoch in which they want astrometric coordinates returned; and the\n"
+     "temperature and barometric pressure, which affect horizon refraction.\n"
+     "See Body.compute() for how to use instances of this class.", /* tp_doc */
      0,				/* tp_traverse */
      0,				/* tp_clear */
      0,				/* tp_richcompare */
@@ -1105,13 +1124,14 @@ static int Planet_setup(Planet *planet, int builtin_index,
 
 static int Planet_init(PyObject *self, PyObject *args, PyObject *kw)
 {
+     int builtin_index;
      PyObject *o = PyObject_GetAttrString(self, "__planet__");
      if (!o) {
           PyErr_SetString(PyExc_TypeError, "internal error: cannot"
                            " init Planet without a __planet__ code");
           return -1;
      }
-     int builtin_index = PyLong_AsLong(o);
+     builtin_index = PyLong_AsLong(o);
      Py_DECREF(o);
      if ((builtin_index == -1) && PyErr_Occurred()) {
           PyErr_SetString(PyExc_TypeError, "internal error: __planet__"
@@ -1296,8 +1316,8 @@ static PyObject* Body_repr(PyObject *body_object)
 
 static PyMethodDef Body_methods[] = {
      {"compute", (PyCFunction) Body_compute, METH_VARARGS | METH_KEYWORDS,
-      "compute the location of the body for the given date or Observer "
-      "(or for the current time if no date is supplied)"},
+      "compute the location of the body for the given date or Observer,"
+      " or for the current time if no date is supplied"},
      {"writedb", (PyCFunction) Body_writedb, METH_NOARGS,
       "return a string representation of the body "
       "appropriate for inclusion in an ephem database file"},
@@ -1682,39 +1702,30 @@ static int Set_gk(PyObject *self, PyObject *value, void *v)
 static PyGetSetDef Body_getset[] = {
      {"name", Get_name, 0, "object name (read-only string)"},
 
-     {"ra", Get_ra, 0, "right ascension (radians that print as hours of arc)"},
-     {"dec", Get_dec, 0, "declination (radians that print as degrees)"},
-     {"g_ra", Get_gaera, 0,
-      "apparent geocentric right ascension"
-      " (radians that print as hours of arc)"},
-     {"g_dec", Get_gaedec, 0,
-      "apparent geocentric declination"
-      " (radians that print as degrees)"},
-     {"a_ra", Get_astrora, 0,
-      "astrometric geocentric right ascension"
-      " (radians that print as hours of arc)"},
-     {"a_dec", Get_astrodec, 0,
-      "astrometric geocentric declination"
-      " (radians that print as degrees)"},
-     {"a_epoch", Get_epoch, 0, "equinox of body's astrometric right"
-      " ascension and declination (Date)"},
-     {"elong", Get_elong, 0, "elongation (radians that print as degrees)"},
+     {"ra", Get_ra, 0, "right ascension" H},
+     {"dec", Get_dec, 0, "declination" D},
+     {"g_ra", Get_gaera, 0, "apparent geocentric right ascension" H},
+     {"g_dec", Get_gaedec, 0, "apparent geocentric declination" D},
+     {"a_ra", Get_astrora, 0, "astrometric geocentric right ascension" H},
+     {"a_dec", Get_astrodec, 0, "astrometric geocentric declination" D},
+     {"a_epoch", Get_epoch, 0,
+      "date giving the equinox of the body's astrometric right"
+      " ascension and declination",
+     },
+     {"elong", Get_elong, 0, "elongation" D},
      {"mag", Get_mag, 0, "magnitude"},
-     {"size", Get_size, 0, "visual size (seconds of arc)"},
-     {"radius", Get_radius, 0, "visual radius (radians that print as degrees)"},
+     {"size", Get_size, 0, "visual size in arcseconds"},
+     {"radius", Get_radius, 0, "visual radius" D},
 
-     {"az", Get_az, 0, "azimuth (radians that print as degrees)"},
-     {"alt", Get_alt, 0, "altitude (radians that print as degrees)"},
+     {"az", Get_az, 0, "azimuth" D},
+     {"alt", Get_alt, 0, "altitude" D},
 
      {"rise_time", Get_rise_time, 0, "rise time"},
-     {"rise_az", Get_rise_az, 0, "rise azimuth"
-      " (radians that print as degrees)"},
+     {"rise_az", Get_rise_az, 0, "azimuth at which the body rises" D},
      {"transit_time", Get_transit_time, 0, "transit time"},
-     {"transit_alt", Get_transit_alt, 0, "transit altitude"
-      " (radians that print as degrees)"},
+     {"transit_alt", Get_transit_alt, 0, "transit altitude" D},
      {"set_time", Get_set_time, 0, "set time"},
-     {"set_az", Get_set_az, 0, "set azimuth"
-      " (radians that print as degrees)"},
+     {"set_az", Get_set_az, 0, "azimuth at which the body sets" D},
      {"circumpolar", Get_circumpolar, 0,
       "whether object remains above the horizon this day"},
      {"neverup", Get_neverup, 0,
@@ -1723,13 +1734,17 @@ static PyGetSetDef Body_getset[] = {
 };
 
 static PyGetSetDef Planet_getset[] = {
-     {"hlong", Get_hlong, 0, "heliocentric longitude"
-      " (radians that print as degrees)"},
-     {"hlat", Get_hlat, 0, "heliocentric latitude"
-      " (radians that print as degrees)"},
-     {"sun_distance", Get_sun_distance, 0, "distance from sun (AU)"},
-     {"earth_distance", Get_earth_distance, 0, "distance from earth (AU)"},
-     {"phase", Get_phase, 0, "phase (percent illuminated)"},
+     {"hlon", Get_hlong, 0,
+      "heliocentric longitude (but Sun().hlon means the hlon of Earth)" D},
+     {"hlat", Get_hlat, 0,
+      "heliocentric latitude (but Sun().hlat means the hlat of Earth)" D},
+     {"sun_distance", Get_sun_distance, 0, "distance from sun in AU"},
+     {"earth_distance", Get_earth_distance, 0, "distance from earth in AU"},
+     {"phase", Get_phase, 0, "phase as percent of the surface illuminated"},
+
+     /* For compatibility with older scripts: */
+     {"hlong", Get_hlong, 0, "heliocentric longitude" D},
+
      {NULL}
 };
 
@@ -1742,33 +1757,25 @@ static PyGetSetDef Planet_getset[] = {
 static PyGetSetDef PlanetMoon_getset[] = {
      {"name", Get_name, 0, "object name (read-only string)"},
 
-     {"a_ra", Get_astrora, 0,
-      "astrometric geocentric right ascension"
-      " (radians that print as hours of arc)"},
-     {"a_dec", Get_astrodec, 0,
-      "astrometric geocentric declination"
-      " (radians that print as degrees)"},
+     {"a_ra", Get_astrora, 0, "astrometric geocentric right ascension" H},
+     {"a_dec", Get_astrodec, 0, "astrometric geocentric declination" D},
 
-     {"g_ra", Get_gaera, 0,
-      "apparent geocentric right ascension"
-      " (radians that print as hours of arc)"},
-     {"g_dec", Get_gaedec, 0,
-      "apparent geocentric declination"
-      " (radians that print as degrees)"},
+     {"g_ra", Get_gaera, 0, "apparent geocentric right ascension" H},
+     {"g_dec", Get_gaedec, 0, "apparent geocentric declination" D},
 
-     {"ra", Get_ra, 0, "right ascension (radians that print as hours of arc)"},
-     {"dec", Get_dec, 0, "declination (radians that print as degrees)"},
+     {"ra", Get_ra, 0, "right ascension" H},
+     {"dec", Get_dec, 0, "declination" D},
 
-     {"az", Get_az, 0, "azimuth (radians that print as degrees)"},
-     {"alt", Get_alt, 0, "altitude (radians that print as degrees)"},
+     {"az", Get_az, 0, "azimuth" D},
+     {"alt", Get_alt, 0, "altitude" D},
 
      {"x", Get_x, 0, "how far east or west of its planet"
-      " the moon lies in the sky (in planet radii, east is positive)"},
+      " the moon lies in the sky in planet radii; east is positive"},
      {"y", Get_y, 0, "how far north or south of its planet"
-      " the moon lies in the sky (in planet radii, south is positive)"},
+      " the moon lies in the sky in planet radii; south is positive"},
      {"z", Get_z, 0, "how much closer or farther from Earth the moon is"
       " than its planet"
-      " (in planet radii, closer to Earth is positive)"},
+      " in planet radii; closer to Earth is positive"},
 
      {"earth_visible", Get_earth_visible, 0, "whether visible from earth"},
      {"sun_visible", Get_sun_visible, 0, "whether visible from sun"},
@@ -1776,36 +1783,28 @@ static PyGetSetDef PlanetMoon_getset[] = {
 };
 
 static PyGetSetDef Moon_getset[] = {
-     {"libration_lat", Get_libration_lat, 0,
-      "lunar libration in latitude (radians that print as degrees)"},
+     {"libration_lat", Get_libration_lat, 0, "lunar libration in latitude" D},
      {"libration_long", Get_libration_long, 0,
-      "lunar libration in longitude (radians that print as degrees)"},
-     {"colong", Get_colong, 0,
-      "lunar selenographic colongitude (radians that print as degrees)"},
+      "lunar libration in longitude" D},
+     {"colong", Get_colong, 0, "lunar selenographic colongitude" D},
      {"moon_phase", Get_moon_phase, 0,
       "fraction of lunar surface illuminated when viewed from earth"},
      {"subsolar_lat", Get_subsolar_lat, 0,
-      "lunar latitude of subsolar point (radians that print as degrees)"},
+      "lunar latitude of subsolar point" D},
      {NULL}
 };
 
 static PyGetSetDef Jupiter_getset[] = {
-     {"cmlI", Get_cmlI, 0,
-      "central meridian longitude, System I (radians that print as degrees)"
-     },
-     {"cmlII", Get_cmlII, 0,
-      "central meridian longitude, System II (radians that print as degrees)"
-     },
+     {"cmlI", Get_cmlI, 0, "central meridian longitude, System I" D},
+     {"cmlII", Get_cmlII, 0, "central meridian longitude, System II" D},
      {NULL}
 };
 
 static PyGetSetDef Saturn_getset[] = {
      {"earth_tilt", Get_earth_tilt, 0,
-      "tilt of rings towards Earth (radians that print as degrees,"
-      " positive for southward tilt and negative for northward)"},
+      "tilt of rings towards Earth, positive for southward tilt," D},
      {"sun_tilt", Get_sun_tilt, 0,
-      "tilt of rings towards Sun radians that print as degrees,"
-      " positive for southward tilt and negative for northward)"},
+      "tilt of rings towards Sun, positive for southward tilt," D},
      {NULL}
 };
 
@@ -1816,9 +1815,9 @@ static PyGetSetDef FixedBody_getset[] = {
      {"_ratio", get_f_ratio, set_f_ratio,
       "ratio of minor to major diameter", VOFF(f_ratio)},
      {"_pa", get_f_pa, set_f_pa, "position angle E of N", VOFF(f_pa)},
-     {"_epoch", getf_mjd, setf_mjd, "epoch for _ra and _dec", VOFF(f_epoch)},
-     {"_ra", getf_rh, setf_rh, "fixed right ascension", VOFF(f_RA)},
-     {"_dec", getf_rd, setf_rd, "fixed declination", VOFF(f_dec)},
+     {"_epoch", getd_mjd, setd_mjd, "epoch for _ra and _dec", VOFF(f_epoch)},
+     {"_ra", getd_rh, setd_rh, "fixed right ascension", VOFF(f_RA)},
+     {"_dec", getd_rd, setd_rd, "fixed declination", VOFF(f_dec)},
      {"_pmra", getf_proper_ra, setf_proper_ra,
       "right ascension proper motion", 0},
      {"_pmdec", getf_proper_dec, setf_proper_dec,
@@ -1910,12 +1909,12 @@ static PyGetSetDef EarthSatellite_getset[] = {
 
      /* results: */
 
-     {"sublat", Get_sublat, 0, "latitude below satellite (degrees north)"},
-     {"sublong", Get_sublong, 0, "longitude below satellite (degrees east)"},
-     {"elevation", Get_elevation, 0, "height above sea level (meters)"},
-     {"range", Get_range, 0, "distance from observer to satellite (meters)"},
+     {"sublat", Get_sublat, 0, "latitude beneath satellite" D},
+     {"sublong", Get_sublong, 0, "longitude beneath satellite" D},
+     {"elevation", Get_elevation, 0, "height above sea level in meters"},
+     {"range", Get_range, 0, "distance from observer to satellite in meters"},
      {"range_velocity", Get_range_velocity, 0,
-      "range rate of change (meters per second)"},
+      "range rate of change in meters per second"},
      {"eclipsed", Get_eclipsed, 0, "whether satellite is in earth's shadow"},
      {NULL}
 };
@@ -1946,6 +1945,8 @@ static PyMemberDef EarthSatellite_members[] = {
  * rather unusual but reflects the fact that all of these are just
  * various wrappers around the same X Obj structure.
  */
+static char body_doc[] =
+     "A celestial body, that can compute() its sky position";
 
 static PyTypeObject BodyType = {
      PyVarObject_HEAD_INIT(NULL, 0)
@@ -1968,7 +1969,7 @@ static PyTypeObject BodyType = {
      0,				/* tp_setattro */
      0,				/* tp_as_buffer */
      Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE, /* tp_flags */
-     0,				/* tp_doc */
+     body_doc,			/* tp_doc */
      0,				/* tp_traverse */
      0,				/* tp_clear */
      0,				/* tp_richcompare */
@@ -2010,7 +2011,7 @@ static PyTypeObject PlanetType = {
      0,				/* tp_setattro */
      0,				/* tp_as_buffer */
      Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE, /* tp_flags */
-     0,				/* tp_doc */
+     body_doc,			/* tp_doc */
      0,				/* tp_traverse */
      0,				/* tp_clear */
      0,				/* tp_richcompare */
@@ -2052,7 +2053,7 @@ static PyTypeObject PlanetMoonType = {
      0,				/* tp_setattro */
      0,				/* tp_as_buffer */
      Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE, /* tp_flags */
-     0,				/* tp_doc */
+     body_doc,			/* tp_doc */
      0,				/* tp_traverse */
      0,				/* tp_clear */
      0,				/* tp_richcompare */
@@ -2094,7 +2095,7 @@ static PyTypeObject JupiterType = {
      0,				/* tp_setattro */
      0,				/* tp_as_buffer */
      Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE, /* tp_flags */
-     0,				/* tp_doc */
+     "Create a Body instance representing Jupiter.",			/* tp_doc */
      0,				/* tp_traverse */
      0,				/* tp_clear */
      0,				/* tp_richcompare */
@@ -2136,7 +2137,7 @@ static PyTypeObject SaturnType = {
      0,				/* tp_setattro */
      0,				/* tp_as_buffer */
      Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE, /* tp_flags */
-     0,				/* tp_doc */
+     "Create a Body instance representing Saturn.",			/* tp_doc */
      0,				/* tp_traverse */
      0,				/* tp_clear */
      0,				/* tp_richcompare */
@@ -2178,7 +2179,7 @@ static PyTypeObject MoonType = {
      0,				/* tp_setattro */
      0,				/* tp_as_buffer */
      Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE, /* tp_flags */
-     0,				/* tp_doc */
+     "Create a Body Instance representing the Moon.",			/* tp_doc */
      0,				/* tp_traverse */
      0,				/* tp_clear */
      0,				/* tp_richcompare */
@@ -2220,7 +2221,7 @@ static PyTypeObject FixedBodyType = {
      0,				/* tp_setattro */
      0,				/* tp_as_buffer */
      Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE, /* tp_flags */
-     0,				/* tp_doc */
+     body_doc,			/* tp_doc */
      0,				/* tp_traverse */
      0,				/* tp_clear */
      0,				/* tp_richcompare */
@@ -2262,7 +2263,7 @@ static PyTypeObject BinaryStarType = {
      0,				/* tp_setattro */
      0,				/* tp_as_buffer */
      Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE, /* tp_flags */
-     0,				/* tp_doc */
+     body_doc,			/* tp_doc */
      0,				/* tp_traverse */
      0,				/* tp_clear */
      0,				/* tp_richcompare */
@@ -2304,7 +2305,7 @@ static PyTypeObject EllipticalBodyType = {
      0,				/* tp_setattro */
      0,				/* tp_as_buffer */
      Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE, /* tp_flags */
-     0,				/* tp_doc */
+     body_doc,			/* tp_doc */
      0,				/* tp_traverse */
      0,				/* tp_clear */
      0,				/* tp_richcompare */
@@ -2346,7 +2347,7 @@ static PyTypeObject HyperbolicBodyType = {
      0,				/* tp_setattro */
      0,				/* tp_as_buffer */
      Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE, /* tp_flags */
-     0,				/* tp_doc */
+     body_doc,			/* tp_doc */
      0,				/* tp_traverse */
      0,				/* tp_clear */
      0,				/* tp_richcompare */
@@ -2388,7 +2389,7 @@ static PyTypeObject ParabolicBodyType = {
      0,				/* tp_setattro */
      0,				/* tp_as_buffer */
      Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE, /* tp_flags */
-     0,				/* tp_doc */
+     body_doc,			/* tp_doc */
      0,				/* tp_traverse */
      0,				/* tp_clear */
      0,				/* tp_richcompare */
@@ -2430,7 +2431,7 @@ static PyTypeObject EarthSatelliteType = {
      0,				/* tp_setattro */
      0,				/* tp_as_buffer */
      Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE,	/* tp_flags */
-     0,				/* tp_doc */
+     body_doc,			/* tp_doc */
      0,				/* tp_traverse */
      0,				/* tp_clear */
      0,				/* tp_richcompare */
@@ -2477,25 +2478,33 @@ static int separation_arg(PyObject *arg, double *lngi, double *lati)
 	  *lati = b->obj.s_dec;
 	  return 0;
      } else if (PySequence_Check(arg) && PySequence_Size(arg) == 2) {
-	  PyObject *lngo, *lato, *lngf, *latf;
+          int rval = -1;
+	  PyObject *lngo = 0, *lato = 0, *lngf = 0, *latf = 0;
 	  lngo = PySequence_GetItem(arg, 0);
-	  if (!lngo) return -1;
+	  if (!lngo) goto fail;
 	  lato = PySequence_GetItem(arg, 1);
-	  if (!lato) return -1;
-	  if (!PyNumber_Check(lngo) || !PyNumber_Check(lato)) goto fail;
+	  if (!lato) goto fail;
+	  if (!PyNumber_Check(lngo) || !PyNumber_Check(lato)) {
+               PyErr_SetString(PyExc_TypeError, err_message);
+               goto fail;
+          }
 	  lngf = PyNumber_Float(lngo);
-	  if (!lngf) return -1;
+	  if (!lngf) goto fail;
 	  latf = PyNumber_Float(lato);
-	  if (!latf) return -1;
+	  if (!latf) goto fail;
 	  *lngi = PyFloat_AsDouble(lngf);
 	  *lati = PyFloat_AsDouble(latf);
-	  Py_DECREF(lngf);
-	  Py_DECREF(latf);
-	  return 0;
+          rval = 0;
+     fail:
+          Py_XDECREF(lngo);
+          Py_XDECREF(lato);
+	  Py_XDECREF(lngf);
+	  Py_XDECREF(latf);
+          return rval;
+     } else {
+          PyErr_SetString(PyExc_TypeError, err_message);
+          return -1;
      }
-fail:
-     PyErr_SetString(PyExc_TypeError, err_message);
-     return -1;
 }
 
 static PyObject* separation(PyObject *self, PyObject *args)
@@ -2811,40 +2820,40 @@ static PyObject *my_eq_ecl(PyObject *self, PyObject *args)
      double mjd, ra, dec, lg, lt;
      if (!PyArg_ParseTuple(args, "ddd:eq_ecl", &mjd, &ra, &dec)) return 0;
      eq_ecl(mjd, ra, dec, &lt, &lg);
-     return Py_BuildValue("(OO)", build_degrees(lg), build_degrees(lt));
+     return Py_BuildValue("NN", build_degrees(lg), build_degrees(lt));
 }
 
 static PyObject *my_ecl_eq(PyObject *self, PyObject *args)
 {
      double mjd, ra, dec, lg, lt;
-     if (!PyArg_ParseTuple(args, "ddd:eq_ecl", &mjd, &lg, &lt)) return 0;
+     if (!PyArg_ParseTuple(args, "ddd:ecl_eq", &mjd, &lg, &lt)) return 0;
      ecl_eq(mjd, lt, lg, &ra, &dec);
-     return Py_BuildValue("(OO)", build_hours(ra), build_degrees(dec));
+     return Py_BuildValue("NN", build_hours(ra), build_degrees(dec));
 }
 
 static PyObject *my_eq_gal(PyObject *self, PyObject *args)
 {
      double mjd, ra, dec, lg, lt;
-     if (!PyArg_ParseTuple(args, "ddd:eq_ecl", &mjd, &ra, &dec)) return 0;
+     if (!PyArg_ParseTuple(args, "ddd:eq_gal", &mjd, &ra, &dec)) return 0;
      eq_gal(mjd, ra, dec, &lt, &lg);
-     return Py_BuildValue("(OO)", build_degrees(lg), build_degrees(lt));
+     return Py_BuildValue("NN", build_degrees(lg), build_degrees(lt));
 }
 
 static PyObject *my_gal_eq(PyObject *self, PyObject *args)
 {
      double mjd, ra, dec, lg, lt;
-     if (!PyArg_ParseTuple(args, "ddd:eq_ecl", &mjd, &lg, &lt)) return 0;
+     if (!PyArg_ParseTuple(args, "ddd:gal_eq", &mjd, &lg, &lt)) return 0;
      gal_eq(mjd, lt, lg, &ra, &dec);
-     return Py_BuildValue("(OO)", build_hours(ra), build_degrees(dec));
+     return Py_BuildValue("NN", build_hours(ra), build_degrees(dec));
 }
 
 static PyObject *my_precess(PyObject *self, PyObject *args)
 {
      double mjd1, mjd2, ra, dec;
-     if (!PyArg_ParseTuple(args, "dddd:eq_ecl", &mjd1, &mjd2, &ra, &dec))
+     if (!PyArg_ParseTuple(args, "dddd:precess", &mjd1, &mjd2, &ra, &dec))
           return 0;
      precess(mjd1, mjd2, &ra, &dec);
-     return Py_BuildValue("(OO)", build_hours(ra), build_degrees(dec));
+     return Py_BuildValue("NN", build_hours(ra), build_degrees(dec));
 }
 
 static PyObject *_next_pass(PyObject *self, PyObject *args)
@@ -2884,7 +2893,7 @@ static PyObject *_next_pass(PyObject *self, PyObject *args)
                riseaz = build_degrees(rs.rs_riseaz);
           }
 
-          if (rs.rs_flags & RS_NOTRANS) {
+          if (rs.rs_flags & (RS_NORISE | RS_NOSET | RS_NOTRANS)) {
                Py_INCREF(Py_None);
                trantm = Py_None;
                Py_INCREF(Py_None);
@@ -2894,7 +2903,7 @@ static PyObject *_next_pass(PyObject *self, PyObject *args)
                tranalt = build_degrees(rs.rs_tranalt);
           }
 
-          if (rs.rs_flags & RS_NOSET) {
+          if (rs.rs_flags & (RS_NORISE | RS_NOSET)) {
                Py_INCREF(Py_None);
                settm = Py_None;
                Py_INCREF(Py_None);
@@ -2922,8 +2931,7 @@ static PyMethodDef libastro_methods[] = {
      {"readdb", readdb, METH_VARARGS, "Read an ephem database entry"},
      {"readtle", readtle, METH_VARARGS, "Read TLE-format satellite elements"},
      {"separation", separation, METH_VARARGS,
-      "Return the angular separation between two objects or positions "
-      "(degrees)"},
+      "Return the angular separation between two objects or positions" D},
 
      {"uranometria", uranometria, METH_VARARGS,
       "given right ascension and declination (in radians), return the page"
