@@ -12,11 +12,12 @@
 
 int get_fields (char *s, int delim, char *fields[]);
 
-#define MAXDBLINE       256     /* longest allowed db line */
+#define MAXDBLINE       512     /* longest allowed db line */
 
 #define FLDSEP          ','     /* major field separator */
 #define SUBFLD          '|'     /* subfield separator */
 #define MAXFLDS 20              /* must be more than on any expected line */
+#define	MAXESGOOD	100	/* max earth satellite good, days */
 
 static char *enm (char *flds[MAXFLDS]);
 static int crack_f (Obj *op, char *flds[MAXFLDS], int nf, char whynot[]);
@@ -72,7 +73,8 @@ db_crack_line (char s[], Obj *op, char nm[][MAXNM], int nnm, char whynot[])
 	    return (-1);
 
 	/* do all the parsing on a copy */
-	(void) strcpy (copy, s);
+	(void) strncpy (copy, s, MAXDBLINE-1);
+	copy[MAXDBLINE-1] = '\0';
 	i = strlen(copy);
 	if (copy[i-1] == '\n')
 	    copy[i-1] = '\0';
@@ -182,6 +184,7 @@ db_write_line (Obj *op, char lp[])
  *   each as far as 69 chars.
  * we detect nonconformance as efficiently as possible.
  * name ends at first '\0', '\r' or '\n'.
+ * set startok/endok.
  * if ok return 0 else return -1
  */
 int
@@ -244,6 +247,18 @@ db_tle (char *name, char *l1, char *l2, Obj *op)
 	op->es_M = (float)tle_fld (l2, 44, 51);
 	op->es_orbit = (int)tle_fld (l2, 64, 68);
 
+	/* limit date range to decay period that changes period by 1% but
+	 * never more than MAXESGOOD.
+	 * es_n is rev/day, es_decay is (rev/day)/day
+	 */
+	if (fabs(op->es_decay) > 0) {
+	    double dt = 0.01*op->es_n/fabs(op->es_decay);
+	    if (dt > MAXESGOOD)
+		dt = MAXESGOOD;
+	    op->es_startok = op->es_epoch - dt;
+	    op->es_endok = op->es_epoch + dt;
+	}
+
 	/* yes! */
 	return (0);
 }
@@ -413,13 +428,13 @@ crack_f (Obj *op, char *flds[MAXFLDS], int nf, char whynot[])
 
 	nsf = get_fields(flds[2], SUBFLD, sflds);
 	f_scansexa (sflds[0], &tmp);
-	op->f_RA = (float) hrrad(tmp);
+	op->f_RA = hrrad(tmp);
 	if (nsf > 1)
 	    op->f_pmRA = (float) 1.327e-11*atod(sflds[1]);/*mas/yr->rad/dy*/
 
 	nsf = get_fields(flds[3], SUBFLD, sflds);
 	f_scansexa (sflds[0], &tmp);
-	op->f_dec = (float) degrad(tmp);
+	op->f_dec = degrad(tmp);
 	if (nsf > 1)
 	    op->f_pmdec = (float)1.327e-11*atod(sflds[1]);/*mas/yr->rad/dy*/
 	if (fabs(op->f_dec) < PI/2)
@@ -430,7 +445,7 @@ crack_f (Obj *op, char *flds[MAXFLDS], int nf, char whynot[])
 	if (nf > 5 && flds[5][0]) {
 	    tmp = op->f_epoch;
 	    crack_year (flds[5], &tmp);
-	    op->f_epoch = (float) tmp;
+	    op->f_epoch = tmp;
 	} else
 	    op->f_epoch = J2000;	/* default */
 
@@ -576,6 +591,18 @@ crack_E (Obj *op, char *flds[MAXFLDS], int nf, char whynot[])
 	if (nf == 12)
 	    op->es_drag = (float) atod (flds[11]);
 
+	/* if not already specified, limit date range to decay period that
+	 * changes period by 1% but never longer than MAXESGOOD.
+	 * es_n is rev/day, es_decay is (rev/day)/day
+	 */
+	if (op->es_startok == 0 && op->es_endok == 0 && fabs(op->es_decay) > 0){
+	    double dt = 0.01*op->es_n/fabs(op->es_decay);
+	    if (dt > MAXESGOOD)
+		dt = MAXESGOOD;
+	    op->es_startok = op->es_epoch - dt;
+	    op->es_endok = op->es_epoch + dt;
+	}
+
 	return (0);
 }
 
@@ -649,13 +676,13 @@ crack_B (Obj *op, char *flds[MAXFLDS], int nf, char whynot[])
 
 	nsf = get_fields(flds[2], SUBFLD, sflds);
 	f_scansexa (sflds[0], &tmp);
-	op->f_RA = (float) hrrad(tmp);
+	op->f_RA = hrrad(tmp);
 	if (nsf > 1)
 	    op->f_pmRA = (float) 1.327e-11*atod(sflds[1]);/*mas/yr->rad/dy*/
 
 	nsf = get_fields(flds[3], SUBFLD, sflds);
 	f_scansexa (sflds[0], &tmp);
-	op->f_dec = (float) degrad(tmp);
+	op->f_dec = degrad(tmp);
 	if (nsf > 1)
 	    op->f_pmdec = (float)1.327e-11*atod(sflds[1]);/*mas/yr->rad/dy*/
 	if (fabs(op->f_dec) < PI/2)
@@ -670,7 +697,7 @@ crack_B (Obj *op, char *flds[MAXFLDS], int nf, char whynot[])
 	if (flds[5][0]) {
 	    tmp = op->f_epoch;
 	    crack_year (flds[5], &tmp);
-	    op->f_epoch = (float) tmp;
+	    op->f_epoch = tmp;
 	} else
 	    op->f_epoch = J2000;	/* default */
 
@@ -999,4 +1026,4 @@ write_P (Obj *op, char lp[])
 }
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: dbfmt.c,v $ $Date: 2007/03/19 08:13:39 $ $Revision: 1.42 $ $Name:  $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: dbfmt.c,v $ $Date: 2009/10/09 21:28:11 $ $Revision: 1.45 $ $Name:  $"};
