@@ -5,7 +5,7 @@
 import ephem._libastro as _libastro
 from math import pi
 
-__version__ = '3.7.3.4'
+__version__ = '3.7.5.1'
 
 twopi = pi * 2.
 halfpi = pi / 2.
@@ -67,10 +67,11 @@ uranometria2000 = _libastro.uranometria2000
 # each planet and moon for which _libastro offers specific algorithms.
 
 for index, classname, name in _libastro.builtin_planets():
-    exec("""
-class %s(_libastro.%s):
-    __planet__ = %r
-""" % (name, classname, index))
+    exec('''
+class {name}(_libastro.{classname}):
+    "Create a Body instance representing {name}"
+    __planet__ = {index!r}
+'''.format(name=name, classname=classname, index=index))
 
 del index, classname, name
 
@@ -182,9 +183,9 @@ def _find_moon_phase(d0, motion, target):
     def f(d):
         _sun.compute(d)
         _moon.compute(d)
-        slong = _libastro.eq_ecl(d, _sun.g_ra, _sun.g_dec)[0]
-        mlong = _libastro.eq_ecl(d, _moon.g_ra, _moon.g_dec)[0]
-        return (mlong - slong - antitarget) % twopi - pi
+        slon = _libastro.eq_ecl(d, _sun.g_ra, _sun.g_dec)[0]
+        mlon = _libastro.eq_ecl(d, _moon.g_ra, _moon.g_dec)[0]
+        return (mlon - slon - antitarget) % twopi - pi
     antitarget = target + pi
     d0 = Date(d0)
     f0 = f(d0)
@@ -234,17 +235,28 @@ class NeverUpError(CircumpolarError): pass
 class AlwaysUpError(CircumpolarError): pass
 
 class Observer(_libastro.Observer):
+    """
+    Observers instances allow you to compute positions of celestial bodies.
+    No parameters to init are taken.
+    Includes a position on the Earth's surface, a time, a temperature, and a pressure.
+    Needed by the compute() method of Body instances.
+    Defaults:
+     time: now
+     temperature: 15 degrees Celsius
+     pressure: 1010 mBar
+     elevation, lat, long: 0
+     epoch: 2000
+    """
     __slots__ = [ 'name' ]
     elev = _libastro.Observer.elevation
 
     def __repr__(self):
         """Return a useful textual representation of this Observer."""
-
         return ('<ephem.Observer date=%r epoch=%r'
-                ' long=%s lat=%s elevation=%sm'
+                ' lon=%s lat=%s elevation=%sm'
                 ' horizon=%s temp=%sC pressure=%smBar>'
                 % (str(self.date), str(self.epoch),
-                   self.long, self.lat, self.elevation,
+                   self.lon, self.lat, self.elevation,
                    self.horizon, self.temp, self.pressure))
 
     def compute_pressure(self):
@@ -268,7 +280,6 @@ class Observer(_libastro.Observer):
             body.compute(self)
             return degrees(offset - sidereal_time() + body.g_ra).znorm
 
-        #original_date = self.date
         if start is not None:
             self.date = start
         sidereal_time = self.sidereal_time
@@ -279,29 +290,60 @@ class Observer(_libastro.Observer):
             ha_to_move = sign * twopi
         d = self.date + ha_to_move / twopi
         result = Date(newton(f, d, d + minute))
-        #self.date = original_date
         return result
 
-    def previous_transit(self, body, start=None):
+    def _previous_transit(self, body, start=None):
         """Find the previous passage of a body across the meridian."""
 
         return self._compute_transit(body, start, -1., 0.)
 
-    def next_transit(self, body, start=None):
+    def _next_transit(self, body, start=None):
         """Find the next passage of a body across the meridian."""
 
         return self._compute_transit(body, start, +1., 0.)
 
-    def previous_antitransit(self, body, start=None):
+    def _previous_antitransit(self, body, start=None):
         """Find the previous passage of a body across the anti-meridian."""
 
         return self._compute_transit(body, start, -1., pi)
 
-    def next_antitransit(self, body, start=None):
+    def _next_antitransit(self, body, start=None):
         """Find the next passage of a body across the anti-meridian."""
 
         return self._compute_transit(body, start, +1., pi)
 
+    def previous_transit(self, body, start=None):
+        """Find the previous passage of a body across the meridian."""
+
+        original_date = self.date
+        d = self._previous_transit(body, start)
+        self.date = original_date
+        return d
+
+    def next_transit(self, body, start=None):
+        """Find the next passage of a body across the meridian."""
+
+        original_date = self.date
+        d = self._next_transit(body, start)
+        self.date = original_date
+        return d
+
+    def previous_antitransit(self, body, start=None):
+        """Find the previous passage of a body across the anti-meridian."""
+
+        original_date = self.date
+        d = self._previous_antitransit(body, start)
+        self.date = original_date
+        return d
+
+    def next_antitransit(self, body, start=None):
+        """Find the next passage of a body across the anti-meridian."""
+
+        original_date = self.date
+        d = self._next_antitransit(body, start)
+        self.date = original_date
+        return d
+
     def disallow_circumpolar(self, declination):
         """Raise an exception if the given declination is circumpolar.
 
@@ -319,7 +361,7 @@ class Observer(_libastro.Observer):
                                 ' above the horizon at latitude %s'
                                 % (declination, self.lat))
 
-    def _riset_helper(self, body, start, rising, previous):
+    def _riset_helper(self, body, start, use_center, rising, previous):
         """Internal function for finding risings and settings."""
 
         if isinstance(body, EarthSatellite):
@@ -330,21 +372,29 @@ class Observer(_libastro.Observer):
                 )
 
         def visit_transit():
-            d = (previous and self.previous_transit(body)
-                 or self.next_transit(body)) # if-then
-            if body.alt + body.radius - self.horizon <= 0:
+            d = (previous and self._previous_transit(body)
+                 or self._next_transit(body)) # if-then
+            if body.alt + body.radius * use_radius - self.horizon <= 0:
                 raise NeverUpError('%r transits below the horizon at %s'
                                    % (body.name, d))
             return d
 
         def visit_antitransit():
-            d = (previous and self.previous_antitransit(body)
-                 or self.next_antitransit(body)) # if-then
-            if body.alt + body.radius - self.horizon >= 0:
+            d = (previous and self._previous_antitransit(body)
+                 or self._next_antitransit(body)) # if-then
+            if body.alt + body.radius * use_radius - self.horizon >= 0:
                 raise AlwaysUpError('%r is still above the horizon at %s'
                                     % (body.name, d))
             return d
 
+        # Determine whether we should offset the result for the radius
+        # of the object being measured, or instead pretend that rising
+        # and setting happens when its center crosses the horizon.
+        if use_center:
+            use_radius = 0.0
+        else:
+            use_radius = 1.0
+
         # Save self.date so that we can restore it before returning.
         original_date = self.date
 
@@ -361,9 +411,11 @@ class Observer(_libastro.Observer):
         body.compute(self)
         heading_downward = (rising == previous) # "==" is inverted "xor"
         if heading_downward:
-            on_lower_cusp = body.alt + body.radius - self.horizon > tiny
+            on_lower_cusp = (body.alt + body.radius * use_radius
+                             - self.horizon > tiny)
         else:
-            on_lower_cusp = body.alt + body.radius - self.horizon < - tiny
+            on_lower_cusp = (body.alt + body.radius * use_radius
+                             - self.horizon < - tiny)
 
         az = body.az
         on_right_side_of_sky = ((rising == (az < pi)) # inverted "xor"
@@ -385,28 +437,28 @@ class Observer(_libastro.Observer):
         def f(d):
             self.date = d
             body.compute(self)
-            return body.alt + body.radius - self.horizon
+            return body.alt + body.radius * use_radius - self.horizon
 
         d = (d0 + d1) / 2.
         result = Date(newton(f, d, d + minute))
         self.date = original_date
         return result
 
-    def previous_rising(self, body, start=None):
+    def previous_rising(self, body, start=None, use_center=False):
         """Move to the given body's previous rising, returning the date."""
-        return self._riset_helper(body, start, True, True)
+        return self._riset_helper(body, start, use_center, True, True)
 
-    def previous_setting(self, body, start=None):
+    def previous_setting(self, body, start=None, use_center=False):
         """Move to the given body's previous setting, returning the date."""
-        return self._riset_helper(body, start, False, True)
+        return self._riset_helper(body, start, use_center, False, True)
 
-    def next_rising(self, body, start=None):
+    def next_rising(self, body, start=None, use_center=False):
         """Move to the given body's next rising, returning the date."""
-        return self._riset_helper(body, start, True, False)
+        return self._riset_helper(body, start, use_center, True, False)
 
-    def next_setting(self, body, start=None):
+    def next_setting(self, body, start=None, use_center=False):
         """Move to the given body's next setting, returning the date."""
-        return self._riset_helper(body, start, False, False)
+        return self._riset_helper(body, start, use_center, False, False)
 
     def next_pass(self, body):
         """Return the next rising, culmination, and setting of a satellite."""
@@ -482,7 +534,7 @@ class Coordinate(object):
                 ' a coordinate or a Body, not an %r' % (type(a).__name__,)
                 )
 
-        # Two arguments are interpreted as (ra, dec) or (long, lat).
+        # Two arguments are interpreted as (ra, dec) or (lon, lat).
 
         elif len(args) == 2:
             self.set(*args)
@@ -506,32 +558,33 @@ class Equatorial(Coordinate):
     to_radec = get
     from_radec = set
 
-class LongLatCoordinate(Coordinate):
-    def set(self, long, lat):
-        self.long, self.lat = degrees(long), degrees(lat)
+class LonLatCoordinate(Coordinate):
+    def set(self, lon, lat):
+        self.lon, self.lat = degrees(lon), degrees(lat)
 
     def get(self):
-        return self.long, self.lat
+        return self.lon, self.lat
 
-class Ecliptic(LongLatCoordinate):
+class Ecliptic(LonLatCoordinate):
     def to_radec(self):
-        return _libastro.ecl_eq(self.epoch, self.long, self.lat)
+        return _libastro.ecl_eq(self.epoch, self.lon, self.lat)
 
     def from_radec(self, ra, dec):
-        self.long, self.lat = _libastro.eq_ecl(self.epoch, ra, dec)
+        self.lon, self.lat = _libastro.eq_ecl(self.epoch, ra, dec)
 
-class Galactic(LongLatCoordinate):
+class Galactic(LonLatCoordinate):
     def to_radec(self):
-        return _libastro.gal_eq(self.epoch, self.long, self.lat)
+        return _libastro.gal_eq(self.epoch, self.lon, self.lat)
 
     def from_radec(self, ra, dec):
-        self.long, self.lat = _libastro.eq_gal(self.epoch, ra, dec)
+        self.lon, self.lat = _libastro.eq_gal(self.epoch, ra, dec)
 
 # For backwards compatibility, provide lower-case names for our Date
-# and Angle classes.
+# and Angle classes, and also allow "Lon" to be spelled "Long".
 
 date = Date
 angle = Angle
+LongLatCoordinate = LonLatCoordinate
 
 # Catalog boostraps.  Each of these functions imports a catalog
 # module, then replaces itself with the function of the same name that
