@@ -1,7 +1,18 @@
 #!/usr/bin/env python
 
-import sys, warnings
-from .ephem_test import *
+import unittest
+import sys
+import warnings
+
+import ephem
+from ephem import (Body, Planet, Moon, Jupiter, Saturn, PlanetMoon,
+                   Date, Observer, readtle, readdb,
+                   FixedBody, EllipticalBody, HyperbolicBody,
+                   ParabolicBody, EarthSatellite,
+                   constellation)
+
+class TestError(Exception):
+    pass
 
 # The attributes which each class of object should support (these
 # lists are used by several of the functions below).
@@ -16,7 +27,7 @@ attribute_list = (
      ('az', 'alt', 'circumpolar', 'neverup', 'rise_time', 'rise_az',
       'transit_time', 'transit_alt', 'set_time', 'set_az')),
     (Planet, False,
-     ('hlong', 'hlat', 'sun_distance', 'earth_distance', 'phase')),
+     ('hlon', 'hlong', 'hlat', 'sun_distance', 'earth_distance', 'phase')),
     (Moon, False,
      ('colong', 'subsolar_lat', 'libration_lat', 'libration_long')),
     (Jupiter, False,
@@ -54,12 +65,12 @@ def predict_attributes(body, was_computed, was_given_observer):
 # Determine whether each kind of body supports the set of attributes
 # we believe it should.
 
-class body_suite(MyTestCase):
+class BodyTests(unittest.TestCase):
     def setUp(self):
-        self.date = date('1955/05/21')
+        self.date = Date('1955/05/21')
 
         self.obs = obs = Observer()
-        obs.lat, obs.long, obs.elev = '33:45:10', '-84:23:37', 320.0
+        obs.lat, obs.lon, obs.elev = '33:45:10', '-84:23:37', 320.0
         obs.date = '1997/2/15'
 
         # Avoid seeing the deprecation warning for old attributes.
@@ -104,7 +115,7 @@ class body_suite(MyTestCase):
                 adjective += 'centrically computed'
             else:
                 adjective = 'uncomputed'
-            raise TestError('accessing %s of %s %s '
+            raise ValueError('accessing %s of %s %s '
                             'raised %r "%s" instead of %r'
                             % (a, adjective, body,
                                t[a], t[a].args[0], p[a]))
@@ -124,16 +135,19 @@ class body_suite(MyTestCase):
         self.compare_attributes(body, True, False)
 
     def test_Named(self):
-        for named_object in (Mercury, Venus, Mars, Jupiter, Saturn,
-                             Uranus, Neptune, Pluto, Sun, Moon,
-                             Phobos, Deimos,
-                             Io, Europa, Ganymede, Callisto,
-                             Mimas, Enceladus, Tethys, Dione, Rhea,
-                             Titan, Hyperion, Iapetus, Ariel, Umbriel,
-                             Titania, Oberon, Miranda):
+        for name in ('Mercury Venus Mars Jupiter Saturn '
+                     'Uranus Neptune Pluto Sun Moon '
+                     'Phobos Deimos '
+                     'Io Europa Ganymede Callisto '
+                     'Mimas Enceladus Tethys Dione Rhea '
+                     'Titan Hyperion Iapetus Ariel Umbriel '
+                     'Titania Oberon Miranda').split():
+            named_object = getattr(ephem, name)
             self.run_body(named_object())
 
-    # For each flavor of user-definable body, 
+    # For each flavor of user-definable body, try building an instance
+    # from both a database entry and from direct-setting its writable
+    # orbital parameter attributes.
 
     def build(self, bodytype, dbentry, attributes):
 
@@ -232,7 +246,7 @@ class body_suite(MyTestCase):
                      '2 20580  28.4694  17.3953 0004117 265.2946  '
                      '94.7172 14.99359833594524'),
             attributes={'name': 'Hubble Telescope',
-                        '_epoch': date('2004') + 296.45910607 - 1,
+                        '_epoch': Date('2004') + 296.45910607 - 1,
                         '_decay': .00000912, '_drag': .59688e-4,
                         '_inc': 28.4694, '_raan': 17.3953,
                         '_e': 4117e-7, '_ap': 265.2946, '_M': 94.7172,
@@ -262,7 +276,7 @@ class body_suite(MyTestCase):
 # indeed a major error occuring in its calculation.  This small test
 # should assure that reasonable values are returned from now on.
 
-class planet_suite(unittest.TestCase):
+class PlanetTests(unittest.TestCase):
     """See whether Jupiter Central Meridian Longitudes look good."""
     def test_jupiter(self):
         j = Jupiter('2008/10/1')
@@ -278,11 +292,8 @@ class planet_suite(unittest.TestCase):
 # Make sure the constellation function forces objects to determine
 # their position before using their right ascension and declination.
 
-class function_suite(unittest.TestCase):
+class FunctionTests(unittest.TestCase):
     def test_constellation(self):
         oneb = readdb('Orion Nebula,f,5.59,-5.45,2,2000.0,')
         oneb.compute('1999/2/28')
         self.assertEqual(constellation(oneb), ('Ori', 'Orion'))
-
-if __name__ == '__main__':
-    unittest.main()
