@@ -28,10 +28,10 @@ def interpret_observer(line):
     line = line.replace('N ', 'N').replace('S ', 'S')
     fields = line.split()
     observer = ephem.Observer()
-    observer.long = ':'.join(re.findall(r'[0-9.]+', fields[1]))
+    observer.lon = ':'.join(re.findall(r'[0-9.]+', fields[1]))
     observer.lat = ':'.join(re.findall(r'[0-9.]+', fields[2]))
     if fields[1].startswith('W'):
-        observer.long *= -1
+        observer.lon *= -1
     if fields[2].startswith('S'):
         observer.lat *= -1
     observer.elevation = float(fields[-1][:-1])
@@ -126,7 +126,7 @@ class Trial(object):
 
 class Astrometric_Trial(Trial):
     @classmethod
-    def matches(self, content):
+    def matches(cls, content):
         return 'Astrometric Positions' in content
 
     def check_data_line(self, line):
@@ -140,7 +140,7 @@ class Astrometric_Trial(Trial):
 
 class Apparent_Geocentric_Trial(Trial):
     @classmethod
-    def matches(self, content):
+    def matches(cls, content):
         return 'Apparent Geocentric Positions' in content
 
     def check_data_line(self, line):
@@ -168,7 +168,7 @@ class Apparent_Geocentric_Trial(Trial):
 
 class Apparent_Topocentric_Trial(Trial):
     @classmethod
-    def matches(self, content):
+    def matches(cls, content):
         return 'Apparent Topocentric Positions' in content
 
     def examine_content(self):
@@ -191,7 +191,7 @@ class Rise_Transit_Set_Trial(Trial):
         self.data = []
 
     @classmethod
-    def matches(self, content):
+    def matches(cls, content):
         return 'Rise  Az.       Transit Alt.       Set  Az.' in content
 
     def examine_content(self):
@@ -316,7 +316,7 @@ The file looks something like:
 
 class Rise_Set_Trial(Trial):
     @classmethod
-    def matches(self, content):
+    def matches(cls, content):
         return 'Rise and Set for' in content
 
     def examine_content(self):
@@ -334,7 +334,7 @@ class Rise_Set_Trial(Trial):
 
         self.observer = o = ephem.Observer()
         o.lat = latstr
-        o.long = longstr
+        o.lon = longstr
         o.elevation = 0
         setup_horizon(o)
 
@@ -404,7 +404,7 @@ class Rise_Set_Trial(Trial):
 
 class Moon_Phases(Trial):
     @classmethod
-    def matches(self, content):
+    def matches(cls, content):
         return 'Phases of the Moon' in content
 
     def examine_content(self):
@@ -454,7 +454,8 @@ class Moon_Phases(Trial):
 class Mixin(object):
     def test_usno(self):
 
-        content = open(self.path).read()
+        with open(self.path) as f:
+            content = f.read()
         g = globals()
         for obj in g.values():
             if (isinstance(obj, type) and issubclass(obj, Trial)
@@ -475,6 +476,3 @@ i = 1
 for path in glob.glob(os.path.dirname(__file__) + '/usno/*.txt'):
     exec('class T%d(unittest.TestCase, Mixin): path = %r' % (i, path))
     i += 1
-
-if __name__ == '__main__':
-    unittest.main()
